@@ -1,20 +1,11 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2009-2013 Luc Saffre
-## This file is part of the Lino project.
-## Lino is free software; you can redistribute it and/or modify 
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## Lino is distributed in the hope that it will be useful, 
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-## GNU General Public License for more details.
-## You should have received a copy of the GNU General Public License
-## along with Lino; if not, see <http://www.gnu.org/licenses/>.
-
 """
 Generic support for :ref:`mldbc`.
 
+:copyright: Copyright 2009-2013 by Luc Saffre.
+:license: BSD, see LICENSE for more details.
+
+
 This includes definition of *babel fields* in your Django Models 
 as well as methods to access these fields.
 
@@ -59,7 +50,7 @@ from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import string_concat
 
-from djangosite.dbutils import monthname
+from djangosite.dbutils import monthname, set_language
 from djangosite.dbutils import dtomy
 
 import north
@@ -302,36 +293,12 @@ def lookup_filter(fieldname,value,**kw):
         del kw[fieldname+lng.suffix+LOOKUP_OP]
     return flt
 
-
     
-def set_language(lang=None):
-    """
-    Thin wrapper around `django.utils.translation`.
-    Activate the given language, or deactivate translations if 
-    the given language is `None` or `'en-us'`.
-    """
-    #~ from django.utils import translation
-    #~ li = self.get_language_info(code)
-    #~ if li is None: or li.index == 0:
-        #~ translation.deactivate()
-    #~ print "20111111 babel.set_language()", lang
-    #~ if lang is None or lang == DEFAULT_LANGUAGE:
-    #~ if lang is not None:
-        #~ if not lang in settings.SITE.AVAILABLE_LANGUAGES:
-            #~ raise Exception("Invalid language %r" % lang)
-    
-    if lang is None or lang == north.DJANGO_DEFAULT_LANGUAGE:
-        #~ locale.setlocale(locale.LC_ALL,'')
-        translation.deactivate()
-    else:
-        north.assert_django_code(lang)
-        translation.activate(lang)
-        
-
     
                         
 
 def format_date(d,format='medium'):
+    if not d: return ''
     return babel_format_date(d, format=format,
         locale=north.to_locale(translation.get_language()))
     
