@@ -491,7 +491,7 @@ class FakeDeserializedObject(base.DeserializedObject):
 class FlushDeferredObjects: 
     """
     Indicator class object. 
-    Fixture may yield a ``dumpy.FlushDeferredObjects`` 
+    Fixture may yield a `FlushDeferredObjects` 
     to indicate that all deferred objects should get saved before going on.
     """
     pass
@@ -602,7 +602,7 @@ class DpyDeserializer:
 Fixture %s decided to not create any object.
 We're sorry, but Django doesn't like that. 
 See <https://code.djangoproject.com/ticket/18213>.
-""" % fp.name)
+""" % module.__name__)
           
         #~ logger.info("Saved %d instances from %s.",self.saved,fp.name)
         
@@ -624,7 +624,7 @@ See <https://code.djangoproject.com/ticket/18213>.
                     count += len(objects)
             
             msg = "Abandoning with %d unsaved instances from %s:%s" % (
-                count,fp.name,s)
+                count,module.__name__,s)
             logger.warning(msg)
             """
             Don't raise an exception. The unsaved instances got lost and 
